==> update-manager_0.142.19.tar.gz: update-manager-0.142.19/UpdateManager/backend/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Integration of package managers into UpdateManager"""
# (c) 2005-2009 Canonical, GPL

import os
import os.path

import gobject


class InstallBackend(gobject.GObject):
    """The abstract backend that can install/remove packages"""

    __gsignals__ = {"action-done": (gobject.SIGNAL_RUN_FIRST,
                                    gobject.TYPE_NONE, (gobject.TYPE_INT, gobject.TYPE_BOOLEAN))}

    (INSTALL, UPDATE) = range(2)

    def __init__(self, window_main):
        """init backend
        takes a gtk main window as parameter
        """
        gobject.GObject.__init__(self)
        self.window_main = window_main

    def commit(self, pkgs_install, pkgs_upgrade, close_on_done):
        """Commit the cache changes """
        raise NotImplemented

    def update(self):
        """Run a update to refresh the package list"""
        raise NotImplemented


def get_backend(*args, **kwargs):
    """Select and return a package manager backend."""
    # try aptdaemon
    if (os.path.exists("/usr/sbin/aptd") and
        not "UPDATE_MANAGER_FORCE_BACKEND_SYNAPTIC" in os.environ):
        # check if the gtkwidgets are installed as well
        try:
            from InstallBackendAptdaemon import InstallBackendAptdaemon
            return InstallBackendAptdaemon(*args, **kwargs)
        except ImportError:
            pass
    # try synaptic
    if (os.path.exists("/usr/sbin/synaptic") and
        not "UPDATE_MANAGER_FORCE_BACKEND_APTDAEMON" in os.environ):
        from InstallBackendSynaptic import InstallBackendSynaptic
        return InstallBackendSynaptic(*args, **kwargs)
    # nothing found, raise
    raise Exception("No working backend found, please try installing "
                    "synaptic or aptdaemon")

==> update-manager_0.150.tar.gz: update-manager-0.150/UpdateManager/backend/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Integration of package managers into UpdateManager"""
# (c) 2005-2009 Canonical, GPL

import os
import os.path

import gobject


class InstallBackend(gobject.GObject):
    """The abstract backend that can install/remove packages"""

    __gsignals__ = {"action-done": (gobject.SIGNAL_RUN_FIRST,
                                    gobject.TYPE_NONE, 
                                    (gobject.TYPE_INT,     # action id
                                     gobject.TYPE_BOOLEAN, # authorized
                                     gobject.TYPE_BOOLEAN) # success
                                    ),
                    }

    (INSTALL, UPDATE) = range(2)

    def __init__(self, window_main):
        """init backend
        takes a gtk main window as parameter
        """
        gobject.GObject.__init__(self)
        self.window_main = window_main

    def commit(self, pkgs_install, pkgs_upgrade, close_on_done):
        """Commit the cache changes """
        raise NotImplemented

    def update(self):
        """Run a update to refresh the package list"""
        raise NotImplemented


def get_backend(*args, **kwargs):
    """Select and return a package manager backend."""
    # try aptdaemon
    if (os.path.exists("/usr/sbin/aptd") and
        not "UPDATE_MANAGER_FORCE_BACKEND_SYNAPTIC" in os.environ):
        # check if the gtkwidgets are installed as well
        try:
            from InstallBackendAptdaemon import InstallBackendAptdaemon
            return InstallBackendAptdaemon(*args, **kwargs)
        except ImportError:
            import logging
            logging.exception("importing aptdaemon")
    # try synaptic
    if (os.path.exists("/usr/sbin/synaptic") and
        not "UPDATE_MANAGER_FORCE_BACKEND_APTDAEMON" in os.environ):
        from InstallBackendSynaptic import InstallBackendSynaptic
        return InstallBackendSynaptic(*args, **kwargs)
    # nothing found, raise
    raise Exception("No working backend found, please try installing "
                    "synaptic or aptdaemon")
